@@ -1,15 +1,14 @@
 data.collection.obj <- new("RzDataCollection")
 rzSettings <- new("RzSettings")
-
-.Rz.path <- system.file(package = "Rz")
 #      .Rz.path <- "/home/masahiro/Documents/R/Rz/Rz/inst"  # for debug
 #      .Rz.path <- "/media/sf_Dropbox/Documents/R/Rz/Rz/inst"  # for debug
 
 .onAttach <- function(lib, pkg){
-  if(exists("winMenuAdd")){
-		temp<-try(winMenuAdd("Rz"),silent=TRUE)
-		if(class(temp)!="try-error"){
-    winMenuAddItem("Rz", gettext("Start"), "Rz()")
+  #     if(exists("winMenuAdd")){
+  if(grepl("mingw", R.Version()$os)){
+    temp<-try(winMenuAdd("Rz"),silent=TRUE)
+    if(class(temp)!="try-error"){
+      winMenuAddItem("Rz", gettext("Start"), "Rz()")
     }
   }
   rzSettings$load()
